@@ -745,9 +745,9 @@ def pathJoin(*paths):
     """Складывает пути, в отличии от os.path.join, складывает абсолютные пути"""
     if len(paths) == 1:
         return paths[0]
-    return reduce(path.join, (x for x 
+    return reduce(path.join, [x for x 
         in (y.startswith("/") and y[1:] or y for y 
-        in paths[1:]) if x and x != "/"), paths[0])
+        in paths[1:]) if x and x != "/"], paths[0])
 
 
 def listDirectory(directory, fullPath=False, onlyDir=False):
